@@ -1,33 +1,31 @@
 # coding=utf-8
-from asyncio import events
-import os
+import asyncio
+import inspect
 import json
+import os
+import re
+import threading
+import time
+from asyncio import events
+from collections import defaultdict
+from copy import deepcopy
+from pathlib import Path
 from typing import Sequence
 
 from maxoptics.base.BaseClient import BaseClient
 from maxoptics.base.BaseDataCls import Material, Waveform
-from maxoptics.error import APIError, InvalidInputError
+from maxoptics.config import Config, BASEDIR
+from maxoptics.constraints.retailer import project_prerun, get_default_async_flag, get_default_async
+from maxoptics.error import APIError, InvalidInputError, TaskFailError
+from maxoptics.models import JSasync, MosProject
+from maxoptics.octopus import monitor_on
 from maxoptics.utils.MosSubmodules import PublicMaterials, UserMaterials, UserWaveforms
 from maxoptics.utils.base import (
     success_print,
     error_print,
     info_print,
 )
-from maxoptics.models import JSasync, MosProject
-from maxoptics.constraints.retailer import project_prerun, get_default_async_flag, get_default_async
-from maxoptics.config import Config, BASEDIR
 from maxoptics.visualizer import get_task_handler, UserImport
-import inspect
-import time
-import threading
-from collections import defaultdict
-from pathlib import Path
-# from urllib3 import exceptions
-from maxoptics.octopus import monitor_on
-from copy import deepcopy
-
-import re
-import asyncio
 
 BETA = Config.BETA
 DEBUG = Config.DEBUG
@@ -105,13 +103,7 @@ class MaxOptics(BaseClient):
         with open(path) as f:
             data = json.load(f)
         public_material = self.search_public_materials()
-        # public_waveform = self.search_waveforms()
         materials = data.get("materials", [])
-        # all_material = []
-        # all_material.extend(materials)
-        # all_material.extend(public_material)
-        # print(public_material)
-        # print(public_waveform)
         waveforms = data.get("waveforms", [])
         project = data["data"]
         exec_list = {"m": {}, "w": {}}
@@ -124,8 +116,6 @@ class MaxOptics(BaseClient):
             exec_list["m"][str(i["id"])] = i["id"]
         for i in self.post(url="create_waveforms", token=self.token, waveforms_info=waveforms)["result"]["result"]:
             exec_list["w"][str(i["original_id"])] = i["id"]
-        # for i in public_waveform:
-        #     exec_list["w"][str(i["id"])] = i["id"]
 
         proj = self.create_project_as(name, silent=True, imported=True, project_type=project_type)
         proj.appendix.update(dict(sweep=project["sweep"]))
@@ -152,9 +142,6 @@ class MaxOptics(BaseClient):
                     continue
                 if component.get(attr, silent=True) != None:
                     if isinstance(l[attr], dict):
-                        # if verbose:
-                        #     print(rep(component.name), ".update(", str(ana(l[attr])),")", sep="")
-                        # component.update(deepcopy(l[attr]))
                         assign_value(l[attr], component)
                     else:
                         if verbose:
@@ -196,6 +183,7 @@ class MaxOptics(BaseClient):
         silent=False,
         imported=False,
         project_type="passive",
+        log_folder=Config.OUTPUTDIR,
     ) -> MosProject:
         self.search_projects()
         try:
@@ -231,13 +219,12 @@ class MaxOptics(BaseClient):
                 raise InvalidInputError
             else:
                 raise InvalidInputError
-            # self.untrash_many_projects(project_id)
         except KeyError as e:
-            res = self.create_project(name=name, project_type=project_type)
+            res = self.create_project(name=name, project_type=project_type, log_folder=log_folder)
             project_id = res.id
             project_version = res.version
 
-        self.projects[name] = MosProject(self, self.token, name, project_type=project_type)
+        self.projects[name] = MosProject(self, self.token, name, project_type=project_type, log_folder=log_folder)
         self.projects[name].id = project_id
         self.projects[name].version = project_version
         info_print("Project ", name, end=" ")
@@ -251,7 +238,7 @@ class MaxOptics(BaseClient):
 
     def ensure_materials(self, materials: Sequence[Material], project_type: str, replace=False):
         """Ensure the materials exist.
-        If replace is set to True, this method will change existing materials attribute.
+        If replace is set to True, this method will change existing materials' attribute.
         This action is kind of DANGEROUS because the same materials might be used in other projects,
         and you may change them unintentionally.
 
@@ -263,22 +250,24 @@ class MaxOptics(BaseClient):
         used_names = UserMaterials(self, project_type).names
         used_ids = UserMaterials(self, project_type).ids
         new: Sequence[Material] = []
-        repeated: Sequence[Material] = []
         for i, info in enumerate(materials):
             if info.name in used_names:
-                info.id = used_ids[i]
-                repeated.append(info)
+                if replace:
+                    new.append(info)
+                for j, used_name in enumerate(used_names):
+                    if used_name == info.name:
+                        if replace:
+                            self.delete_material(used_ids[j])
             else:
                 new.append(info)
 
         self.__create_materials([_.to_dict() for _ in new], project_type)
-        if replace:
-            self.__change_materials([_.to_dict2() for _ in repeated])
+
         self.user_materials.reload()
 
     def ensure_waveforms(self, waveforms: Sequence[Waveform], replace=False):
         """Ensure the waveforms exist.
-        If replace is set to True, this method will change existing waveforms attribute.
+        If replace is set to True, this method will change existing waveforms' attribute.
         This action is kind of DANGEROUS because the same waveforms might be used in other projects,
         and you may change them unintentionally.
 
@@ -290,21 +279,21 @@ class MaxOptics(BaseClient):
         used_names = UserWaveforms(self).names
         used_ids = UserWaveforms(self).ids
         new = []
-        repeated = []
         for i, info in enumerate(waveforms):
             if info.name in used_names:
-                info.id = used_ids[i]
-                repeated.append(info)
+                if replace:
+                    new.append(info)
+                for j, used_name in enumerate(used_names):
+                    if used_name == info.name:
+                        if replace:
+                            self.delete_waveform(used_ids[j])
             else:
                 new.append(info)
 
         self.__create_waveforms([_.to_dict() for _ in new])
-        if replace:
-            self.__change_waveforms([_.to_dict() for _ in repeated])
+
         self.user_waveforms.reload()
 
-
-
     def search_materials(self, url="") -> list:
         """
         搜索材料
@@ -347,9 +336,8 @@ class MaxOptics(BaseClient):
             self.waveforms = result["result"]["result"]
             return result["result"]["result"]
 
-    def create_project(self, name: str, project_type="passive") -> MosProject:
+    def create_project(self, name: str, project_type="passive", log_folder=Config.OUTPUTDIR) -> MosProject:
         """ """
-        # if type == 'passive':
         path = Path(BASEDIR) / "static_modules" / "ProjectSample.json"
         with open(path, "r", encoding="utf8") as f:
             empty_project_data = json.load(f)
@@ -365,7 +353,7 @@ class MaxOptics(BaseClient):
             error_print("Project creation Failed, %s" % result["result"]["msg"])
             raise APIError(result["result"]["msg"])
         else:
-            self.projects[name] = MosProject(self, self.token, name, project_type=project_type)
+            self.projects[name] = MosProject(self, self.token, name, project_type=project_type, log_folder=log_folder)
             self.projects[name].id = result["result"]["id"]
             self.projects[name].type = project_type
             self.projects[name].version = result["result"]["version"]
@@ -396,19 +384,19 @@ class MaxOptics(BaseClient):
         else:
             success_print("Project", proj.name, "Saved.")
 
-    def create_task(self, proj: MosProject, task_type=None, project_type="", __timeout__=-1, *args, **kws):
+    def create_task(self, project: MosProject, task_type=None, project_type="", __timeout__=-1, *args, **kws):
         """ """
         mode = ""
-        if isinstance(proj, int):
+        if isinstance(project, int):
             if "async_flag" in kws:
                 async_flag = kws.pop("async_flag")
             else:
                 async_flag = get_default_async(project_type, task_type)
 
-                params = dict(
-                    **{"token": self.token, "project_id": proj, "tasktype": task_type},
-                    **({"async": async_flag} if async_flag else {}),
-                )
+            params = dict(
+                **{"token": self.token, "project_id": project, "tasktype": task_type},
+                **({"async": async_flag} if async_flag else {}),
+            )
         else:
             kws = defaultdict(lambda: False, kws)
 
@@ -418,12 +406,12 @@ class MaxOptics(BaseClient):
             task_info = kws.pop("task_info") or None
             kws["link_task_id"]
             link_task_id = kws.pop("link_task_id") or []
-            task_type = task_type if task_type else proj.solver_type
+            task_type = task_type if task_type else project.solver_type
 
             if "async_flag" in kws:
                 async_flag = kws.pop("async_flag")
             else:
-                async_flag = get_default_async_flag(proj)
+                async_flag = get_default_async_flag(project)
 
             if BETA:
                 print(f"RUN TASK WITH {task_type = }, {async_flag = }, {dep_task = }")
@@ -432,22 +420,22 @@ class MaxOptics(BaseClient):
                 task_type = "fde"
             if task_type.upper() == "EME_SWEEP":
                 # TODO: This part should rm
-                proj.solver["propagation"] = 1
+                project.solver["propagation"] = 1
                 if not kws["start"] and kws["start"] and kws["stop"] and kws["number_of_points"] and kws["para"]:
                     error_print("Please Input value of start, stop, number_of_points, para")
                     raise InvalidInputError
                 if "stop" in kws:
-                    proj.solver["stop"] = kws["stop"]
-                proj.solver["start"] = kws["start"] if "start" in kws else 0
-                proj.solver["number_of_points"] = kws["number_of_points"] if "number_of_points" in kws else 5
-                proj.solver["parameter"] = kws["para"] if "para" in kws else 0
-                proj.save()
+                    project.solver["stop"] = kws["stop"]
+                project.solver["start"] = kws["start"] if "start" in kws else 0
+                project.solver["number_of_points"] = kws["number_of_points"] if "number_of_points" in kws else 5
+                project.solver["parameter"] = kws["para"] if "para" in kws else 0
+                project.save()
             else:
                 for k in kws:
-                    proj.solver[k] = kws[k]
+                    project.solver[k] = kws[k]
 
             params = dict(
-                **{"token": self.token, "project_id": proj.id, "tasktype": task_type},
+                **{"token": self.token, "project_id": project.id, "tasktype": task_type},
                 **({"async": async_flag} if async_flag else {}),
                 **({"dep_task": dep_task} if dep_task else {}),
                 **({"task_info": task_info} if task_info else {}),
@@ -456,18 +444,19 @@ class MaxOptics(BaseClient):
         result = self.post(**params)
         if result["success"] is False:
             error_print("Task startup Failed, %s" % result["result"]["msg"])
-            raise Exception
+            raise TaskFailError("Task startup Failed, %s" % result["result"]["msg"])
         else:
-            info_print("Project ", proj.name, end=" ")
+            info_print("Project ", project.name, end=" ")
             success_print(
                 "Task started. id {}.\n You can open file {} to check task status".format(
                     str(result["result"]["id"]),
-                    str(Config.OUTPUTDIR / (str(proj.name) + "_" + str(result["result"]["id"])) / "log" / "status.log"),
+                    str(project.log_folder / (
+                        str(project.name) + "_" + str(result["result"]["id"])) / "log" / "terminal.log"),
                 )
             )
             task = dict(**result["result"], **{"task_type": task_type})
-            res = monitor_on(proj, task, self.get_tasks, self.token, mode)
-            proj.running_tasks.append(res)
+            res = monitor_on(project, task, self.get_tasks, self.token, mode)
+            project.running_tasks.append(res)
 
             if __timeout__ == -1:
                 task = res
@@ -563,6 +552,20 @@ class MaxOptics(BaseClient):
         task.update_status()
         return task
 
+    def delete_material(self, material_id):
+        params = {"token": self.token, "material_id": material_id}
+        result = self.post(url="delete_material", **params)
+        if result["success"] is False:
+            error_print("Delete Material Failed, %s" % result["result"]["msg"])
+            raise APIError("Delete Material Failed, %s" % result["result"]["msg"])
+
+    def delete_waveform(self, waveform_id):
+        params = {"token": self.token, "waveform_id": waveform_id}
+        result = self.post(url="delete_waveform", **params)
+        if result["success"] is False:
+            error_print("Delete Waveform Failed, %s" % result["result"]["msg"])
+            raise APIError("Delete Waveform Failed, %s" % result["result"]["msg"])
+
     def __untrash_many_projects(self, id):
         params = {"token": self.token, "projects_id": [id]}
         result = self.post(url="untrash_many_projects", **params)
@@ -623,7 +626,7 @@ class MaxOptics(BaseClient):
 
     def get_material_table_data(self, material_id):
         params = {"token": self.token, "material_id": material_id}
-        result = self.post(url = "get_material_table_data", **params)
+        result = self.post(url="get_material_table_data", **params)
         if result["success"] is False:
             error_print("Material table data fetching failed, %s" % result["result"]["msg"])
         else:
@@ -633,7 +636,6 @@ class MaxOptics(BaseClient):
     def get_uploader():
         return UserImport()
 
-
     def __del__(self):
         self.token = ""
         # self.logout()
