@@ -8,30 +8,19 @@ import os
 from contextlib import contextmanager
 from functools import partial
 from pathlib import Path
-from typing import ByteString
 
 import numpy as np
 import pandas as pd
 # Functools
 import requests
-import urllib3
 
 import maxoptics.utils.base as base
+from maxoptics.base.BaseClient import BaseClient
 # MOS imports
 from maxoptics.config import Config
-from maxoptics.sdk import BaseClient
 from maxoptics.utils.__visualizer__ import Index as _Index
 from maxoptics.utils.decorators import __post__, data_parser
 
-# Type Check
-
-# Accessories
-
-try:
-    import readline
-except:
-    pass
-
 BETA = Config.BETA
 
 
@@ -151,19 +140,19 @@ class V0_3_API(WhaleClients):
 
 class FDTDResultHandler(V0_4_API):
     @__post__
-    def passive_fdtd_fd_result_option(self, target: str, monitorIndex: int):
-        return {"target": target, "pub": {"taskId": self.task_id, "monitorIndex": self.Index(monitorIndex)}}
+    def passive_fdtd_fd_result_option(self, target: str, monitor_index: int):
+        return {"target": target, "pub": {"taskId": self.task_id, "monitorIndex": self.Index(monitor_index)}}
 
     @data_parser
     @__post__
     def passive_fdtd_fd_result_chart(
-        self, target: str, monitorIndex: int, attribute: str, operation: str, log=False, **kwargs
+        self, target: str, monitor_index: int, attribute: str, operation: str, log=False, **kwargs
     ):
         return {
             "target": target,
             "pub": {  # pub
                 "taskId": self.task_id,
-                "monitorIndex": self.Index(monitorIndex),
+                "monitorIndex": self.Index(monitor_index),
                 "attribute": attribute,
                 "operation": operation,
                 "log": log,
@@ -172,19 +161,19 @@ class FDTDResultHandler(V0_4_API):
         }
 
     @__post__
-    def passive_fdtd_td_result_option(self, target: str, monitorIndex: int):
-        return {"target": target, "pub": {"taskId": self.task_id, "monitorIndex": self.Index(monitorIndex)}}
+    def passive_fdtd_td_result_option(self, target: str, monitor_index: int):
+        return {"target": target, "pub": {"taskId": self.task_id, "monitorIndex": self.Index(monitor_index)}}
 
     @data_parser
     @__post__
     def passive_fdtd_td_result_chart(
-        self, target: str, monitorIndex: int, attribute: str, operation: str, log=False, **kwargs
+        self, target: str, monitor_index: int, attribute: str, operation: str, log=False, **kwargs
     ):
         return {
             "target": target,
             "pub": {  # pub
                 "taskId": self.task_id,
-                "monitorIndex": self.Index(monitorIndex),
+                "monitorIndex": self.Index(monitor_index),
                 "attribute": attribute,
                 "operation": operation,
                 "log": log,
@@ -193,19 +182,19 @@ class FDTDResultHandler(V0_4_API):
         }
 
     @__post__
-    def passive_fdtd_sweep_option(self, target: str, monitorIndex: int):
-        return {"target": target, "pub": {"taskId": self.task_id, "monitorIndex": self.Index(monitorIndex)}}
+    def passive_fdtd_sweep_option(self, target: str, monitor_index: int):
+        return {"target": target, "pub": {"taskId": self.task_id, "monitorIndex": self.Index(monitor_index)}}
 
     @data_parser
     @__post__
     def passive_fdtd_sweep_chart(
-        self, target: str, monitorIndex: int, attribute: str, operation: str, log=False, **kwargs
+        self, target: str, monitor_index: int, attribute: str, operation: str, log=False, **kwargs
     ):
         return {
             "target": target,
             "pub": {  # pub
                 "taskId": self.task_id,
-                "monitorIndex": self.Index(monitorIndex),
+                "monitorIndex": self.Index(monitor_index),
                 "attribute": attribute,
                 "operation": operation,
                 "log": log,
@@ -216,19 +205,19 @@ class FDTDResultHandler(V0_4_API):
 
 class FDTDIndexResultHandler(V0_4_API):
     @__post__
-    def passive_fdtd_index_monitor_option(self, target: str, monitorIndex: int):
-        return {"target": target, "pub": {"taskId": self.task_id, "monitorIndex": self.Index(monitorIndex)}}
+    def passive_fdtd_index_monitor_option(self, target: str, monitor_index: int):
+        return {"target": target, "pub": {"taskId": self.task_id, "monitorIndex": self.Index(monitor_index)}}
 
     @data_parser
     @__post__
     def passive_fdtd_index_monitor_chart(
-        self, target: str, monitorIndex: int, attribute: str, operation: str, log=False, **kwargs
+        self, target: str, monitor_index: int, attribute: str, operation: str, log=False, **kwargs
     ):
         return {
             "target": target,
             "pub": {  # pub
                 "taskId": self.task_id,
-                "monitorIndex": self.Index(monitorIndex),
+                "monitorIndex": self.Index(monitor_index),
                 "attribute": attribute,
                 "operation": operation,
                 "log": log,
@@ -239,19 +228,19 @@ class FDTDIndexResultHandler(V0_4_API):
 
 class FDEResultHandler(V0_4_API):
     @__post__
-    def passive_fde_options(self, target: str, monitorIndex: int):
-        return {"target": target, "pub": {"taskId": self.task_id, "monitorIndex": self.Index(monitorIndex)}}
+    def passive_fde_options(self, target: str, monitor_index: int):
+        return {"target": target, "pub": {"taskId": self.task_id, "monitorIndex": self.Index(monitor_index)}}
 
     @data_parser
     @__post__
     def passive_fde_result_chart(
-        self, target: str, monitorIndex: int, attribute: str, operation: str, log=False, **kwargs
+        self, target: str, monitor_index: int, attribute: str, operation: str, log=False, **kwargs
     ):
         return {
             "target": target,
             "pub": {  # pub
                 "taskId": self.task_id,
-                "monitorIndex": self.Index(monitorIndex),
+                "monitorIndex": self.Index(monitor_index),
                 "attribute": attribute,
                 "operation": operation,
                 "log": log,
@@ -342,17 +331,17 @@ class EMEResultHandler(V0_4_API):
         return {"data": np.transpose(list(smatrixs)), "legend": legend, "horizontal": sweep_spans}
 
     @__post__
-    def passive_eme_fd_result_options(self, target: str, monitorIndex: int):
-        return {"target": target, "pub": {"taskId": self.task_id, "monitorIndex": self.Index(monitorIndex)}}
+    def passive_eme_fd_result_options(self, target: str, monitor_index: int):
+        return {"target": target, "pub": {"taskId": self.task_id, "monitorIndex": self.Index(monitor_index)}}
 
     @data_parser
     @__post__
-    def passive_eme_fd_result_chart(self, target: str, monitorIndex: int, attribute: str, operation: str, **kwargs):
+    def passive_eme_fd_result_chart(self, target: str, monitor_index: int, attribute: str, operation: str, **kwargs):
         return {
             "target": target,
             "pub": {  # pub
                 "taskId": self.task_id,
-                "monitorIndex": self.Index(monitorIndex),
+                "monitorIndex": self.Index(monitor_index),
                 "attribute": attribute,
                 "operation": operation,
             },
@@ -483,19 +472,19 @@ class PDResultHandler(V0_3_API):
             del res
 
     @__post__
-    def passive_fdtd_fd_result_option(self, target: str, monitorIndex: int):
-        return {"target": target, "pub": {"taskId": self.task_id, "monitorIndex": self.Index(monitorIndex)}}
+    def passive_fdtd_fd_result_option(self, target: str, monitor_index: int):
+        return {"target": target, "pub": {"taskId": self.task_id, "monitorIndex": self.Index(monitor_index)}}
 
     @data_parser
     @__post__
     def passive_fdtd_fd_result_chart(
-        self, target: str, monitorIndex: int, attribute: str, operation: str, log=False, **kwargs
+        self, target: str, monitor_index: int, attribute: str, operation: str, log=False, **kwargs
     ):
         return {
             "target": target,
             "pub": {  # pub
                 "taskId": self.task_id,
-                "monitorIndex": self.Index(monitorIndex),
+                "monitorIndex": self.Index(monitor_index),
                 "attribute": attribute,
                 "operation": operation,
                 "log": log,
@@ -571,19 +560,19 @@ class ModulatorResultHandler(V0_3_API):
             del res
 
     @__post__
-    def passive_fde_options(self, target: str, monitorIndex: int):
-        return {"target": target, "pub": {"taskId": self.task_id, "monitorIndex": self.Index(monitorIndex)}}
+    def passive_fde_options(self, target: str, monitor_index: int):
+        return {"target": target, "pub": {"taskId": self.task_id, "monitorIndex": self.Index(monitor_index)}}
 
     @data_parser
     @__post__
     def passive_fde_result_chart(
-        self, target: str, monitorIndex: int, attribute: str, operation: str, log=False, **kwargs
+        self, target: str, monitor_index: int, attribute: str, operation: str, log=False, **kwargs
     ):
         return {
             "target": target,
             "pub": {  # pub
                 "taskId": self.task_id,
-                "monitorIndex": self.Index(monitorIndex),
+                "monitorIndex": self.Index(monitor_index),
                 "attribute": attribute,
                 "operation": operation,
                 "log": log,
